(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "tsparticles-engine", "./Utils"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    exports.StrokeColorUpdater = void 0;
    const tsparticles_engine_1 = require("tsparticles-engine");
    const Utils_1 = require("./Utils");
    class StrokeColorUpdater {
        constructor(container) {
            this.container = container;
        }
        init(particle) {
            const container = this.container, options = particle.options;
            const stroke = (0, tsparticles_engine_1.itemFromSingleOrMultiple)(options.stroke, particle.id, options.reduceDuplicates);
            particle.strokeWidth = (0, tsparticles_engine_1.getRangeValue)(stroke.width) * container.retina.pixelRatio;
            particle.strokeOpacity = (0, tsparticles_engine_1.getRangeValue)(stroke.opacity ?? 1);
            particle.strokeAnimation = stroke.color?.animation;
            const strokeHslColor = (0, tsparticles_engine_1.rangeColorToHsl)(stroke.color) ?? particle.getFillColor();
            if (strokeHslColor) {
                particle.strokeColor = (0, tsparticles_engine_1.getHslAnimationFromHsl)(strokeHslColor, particle.strokeAnimation, container.retina.reduceFactor);
            }
        }
        isEnabled(particle) {
            const color = particle.strokeAnimation, { strokeColor } = particle;
            return (!particle.destroyed &&
                !particle.spawning &&
                !!color &&
                ((strokeColor?.h.value !== undefined && strokeColor.h.enable) ||
                    (strokeColor?.s.value !== undefined && strokeColor.s.enable) ||
                    (strokeColor?.l.value !== undefined && strokeColor.l.enable)));
        }
        update(particle, delta) {
            if (!this.isEnabled(particle)) {
                return;
            }
            (0, Utils_1.updateStrokeColor)(particle, delta);
        }
    }
    exports.StrokeColorUpdater = StrokeColorUpdater;
});
